==> zope.site-3.8.0.zip: zope.site-3.8.0/src/zope/site/tests/test_localsitemanager.py <==
##############################################################################
#
# Copyright (c) 2007 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Local sitemanager tests.

$Id: test_localsitemanager.py 106551 2009-12-15 18:22:39Z hannosch $
"""
import unittest

from zope.interface import Interface
from zope.copypastemove import ObjectCopier
from zope import site
from zope.site.folder import Folder
import zope.site.testing


class I1(Interface):
    pass


class TestLocalSiteManager(unittest.TestCase):

    def setUp(self):
        zope.site.testing.siteSetUp()
        self.util = object()
        self.root = Folder()
        self.root['site'] = Folder()
        subfolder  = self.root['site']
        subfolder.setSiteManager(site.LocalSiteManager(subfolder))
        subfolder.getSiteManager().registerUtility(self.util, I1)

    def tearDown(self):
        zope.site.testing.siteTearDown()

    def testCopy(self):
        self.assert_(
            self.root['site'].getSiteManager().getUtility(I1) is self.util)

        copier = ObjectCopier(self.root['site'])
        copier.copyTo(self.root, 'copied_site')

        self.assert_(
            self.root['copied_site'].getSiteManager().getUtility(I1) is not self.util)

def test_suite():
    return unittest.TestSuite((
        unittest.makeSuite(TestLocalSiteManager),
        ))

==> zope.site-3.9.1.zip: zope.site-3.9.1/src/zope/site/tests/test_localsitemanager.py <==
##############################################################################
#
# Copyright (c) 2007 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Local sitemanager tests.

$Id: test_localsitemanager.py 107325 2009-12-29 23:17:12Z hannosch $
"""
import unittest

from zope.interface import Interface
from zope import site
from zope.site.folder import Folder
import zope.site.testing


class I1(Interface):
    pass


class TestLocalSiteManager(unittest.TestCase):

    def setUp(self):
        zope.site.testing.siteSetUp()
        self.util = object()
        self.root = Folder()
        self.root['site'] = Folder()
        subfolder  = self.root['site']
        subfolder.setSiteManager(site.LocalSiteManager(subfolder))
        subfolder.getSiteManager().registerUtility(self.util, I1)

    def tearDown(self):
        zope.site.testing.siteTearDown()

    def testPersistence(self):
        from pickle import dumps, loads
        self.assert_(
            self.root['site'].getSiteManager().getUtility(I1) is self.util)

        data = dumps(self.root['site'])
        self.root['copied_site'] = loads(data)

        self.assert_(
            self.root['copied_site'].getSiteManager().getUtility(I1) is not self.util)

def test_suite():
    return unittest.TestSuite((
        unittest.makeSuite(TestLocalSiteManager),
        ))
